@@ -104,7 +104,7 @@ reconstruct.redist_plans <- function(data, old) {
 #' The first two columns of the data frame will be \code{draw}, a factor indexing
 #' the simulation draw, and \code{district}, an integer indexing the districts
 #' within a plan. The data frame will therefore have \code{n_sims*ndists} rows.
-#' As a data frame, the usual \code{\link{dplyr}} methods will work.
+#' As a data frame, the usual `dplyr` methods will work.
 #'
 #' Other useful methods for \code{redist_plans} objects:
 #' * \code{\link{summary.redist_plans}}
@@ -506,8 +506,18 @@ rbind.redist_plans <- function(..., deparse.level = 1) {
         }
     }
 
-    ret <- bind_rows(lapply(objs, dplyr::as_tibble), .id = "chain")
-    ret$chain <- as.integer(ret$chain)
+    ret <- lapply(seq_along(objs), function(i) {
+        out <- objs[[i]] |>
+            dplyr::as_tibble()
+
+        if (!'chain' %in% names(out)) {
+            out$chain <- i
+        }
+        out
+    }) |>
+        dplyr::bind_rows()
+
+    #ret$chain <- factor_combine(ret$chain)
     ret <- reconstruct.redist_plans(ret, objs[[1]])
     attr(ret, "compactness") <- comp
     attr(ret, "constraints") <- constr
