@@ -110,9 +110,6 @@ redist_shortburst <- function(map, score_fn = NULL, stop_at = NULL,
 
     score_fn <- rlang::as_closure(score_fn)
     stopifnot(is.function(score_fn))
-    if (!is.numeric(stop_at)) {
-        stop_at <- Inf
-    }
 
     if (compactness < 0)
         cli_abort("{.arg compactness} must be non-negative.")
@@ -166,7 +163,8 @@ redist_shortburst <- function(map, score_fn = NULL, stop_at = NULL,
     }
 
     pop <- map[[attr(map, "pop_col")]]
-    if (any(pop >= get_target(map))) {
+    if ((backend == 'flip' && any(pop >= get_target(map))) ||
+        (backend == 'mergesplit' && any(pop >= pop_bounds[3]))) {
         too_big <- as.character(which(pop >= pop_bounds[3]))
         cli_abort(c("Unit{?s} {too_big} ha{?ve/s/ve}
                     population larger than the district target.",
@@ -179,19 +177,10 @@ redist_shortburst <- function(map, score_fn = NULL, stop_at = NULL,
     if (backend == "mergesplit") {
         control = list(adapt_k_thresh=adapt_k_thresh, do_mh=reversible)
         if (is.null(fixed_k)) {
-            # kind of hacky -- extract k=... from outupt
-            if (!requireNamespace("utils", quietly = TRUE)) stop()
-            out <- utils::capture.output({
-                x <- ms_plans(1, adj, init_plan, counties, pop, ndists, pop_bounds[2],
-                    pop_bounds[1], pop_bounds[3], compactness,
-                    list(), control, 0L, 1L, verbosity = 3)
-            }, type = "output")
-            rm(x)
-            k <- as.integer(stats::na.omit(stringr::str_match(out, "Using k = (\\d+)")[, 2]))
-            if (length(k) == 0)
-                cli_abort(c("Adaptive {.var k} not found. This error should not happen.",
-                    ">" = "Please file an issue at
-                            {.url https://github.com/alarm-redist/redist/issues/new}"))
+            x <- ms_plans(1, adj, init_plan, counties, pop, ndists, pop_bounds[2],
+                          pop_bounds[1], pop_bounds[3], compactness,
+                          list(), control, 0L, 1L, verbosity = 0)
+            k <- x$est_k
         } else {
             k = fixed_k
         }
@@ -227,6 +216,12 @@ redist_shortburst <- function(map, score_fn = NULL, stop_at = NULL,
     rescale <- 1 - maximize * 2
 
     cur_best_scores <- score_fn(matrix(init_plan, ncol = 1))
+    score_init = cur_best_scores
+    if (!is.numeric(stop_at)) {
+        stop_at <- -Inf
+    } else {
+        stop_at = rescale * stop_at
+    }
     if (!is.matrix(cur_best_scores)) {
         cur_best_scores = matrix(cur_best_scores, ncol=1)
         rownames(cur_best_scores) = "score"
@@ -309,7 +304,7 @@ redist_shortburst <- function(map, score_fn = NULL, stop_at = NULL,
             out_mat[, idx] <- cur_best[, out_idx]
             scores[idx, ] <- cur_best_scores[, out_idx] * rescale
 
-            if (any(colSums(cur_best_scores >= stop_at) == dim_score)) {
+            if (any(colSums(cur_best_scores <= stop_at) == dim_score)) {
                 converged = TRUE
                 break
             }
@@ -321,15 +316,15 @@ redist_shortburst <- function(map, score_fn = NULL, stop_at = NULL,
         storage.mode(out_mat) <- "integer"
 
         pareto_scores = t(cur_best_scores * rescale)
-        pareto_scores = pareto_scores[order(pareto_scores[, 1]), , drop=FALSE]
+        ord = order(pareto_scores[, 1])
 
         out <- new_redist_plans(out_mat[, out_idx, drop = FALSE], map, "shortburst",
             wgt = NULL, resampled = FALSE,
             n_bursts = burst,
             backend = backend,
             converged = converged,
-            pareto_front = cur_best,
-            pareto_scores = pareto_scores,
+            pareto_front = cur_best[, ord, drop=FALSE],
+            pareto_scores = pareto_scores[ord, , drop=FALSE],
             version = packageVersion("redist"),
             score_fn = deparse(substitute(score_fn)))
         score_mat = matrix(rep(scores[out_idx, ], each = ndists), ncol = dim_score)
@@ -339,7 +334,7 @@ redist_shortburst <- function(map, score_fn = NULL, stop_at = NULL,
 
         out <- add_reference(out, init_plan, "<init>")
         idx_cols = ncol(out) - dim_score:1
-        out[1:ndists, idx_cols] <- matrix(rep(scores[1, ], each = ndists), ncol = dim_score)
+        out[1:ndists, idx_cols] <- matrix(rep(score_init, each = ndists), ncol = dim_score)
     } else {
         out <- new_redist_plans(cur_best, map, "shortburst",
                                 wgt = NULL, resampled = FALSE,
@@ -512,7 +507,7 @@ scorer_multisplits <- function(map, counties) {
 #' @rdname scorers
 #' @order 6
 #'
-#' @param perim_df perimeter distance dataframe from [prep_perims()]
+#' @param perim_df perimeter distance dataframe from [redistmetrics::prep_perims()]
 #' @param areas area of each precinct (ie `st_area(map)`)
 #' @param m the m-th from the bottom Polsby Popper to return as the score. Defaults to 1,
 #' the minimum Polsby Popper score
