@@ -1,8 +1,8 @@
+#pragma once
 #ifndef CLOSEST_ADJ_POP_H
 #define CLOSEST_ADJ_POP_H
 
-#include <Rcpp.h>
-using namespace Rcpp;
+#include "smc_base.h"
 
 int closest_adj_pop(IntegerVector adj,
                 int i_dist,
